# Widen Client
A Python client for interacting with Widen v2 API.

Documentation: https://widenv2.docs.apiary.io/#

## Installation
This client is privately hosted. To install, run

```bash
pipenv install -e git+ssh://git@github.com/gagosian/widen-client.git#egg=widen-client

```

## Usage
```python
from widen_client import Widen

widen = Widen(access_token='...')

widen.assets.search('dBnumber:CHUNG 2021.0001')

widen.assets.get('46579cd6-f58d-49ed-b4af-ea32c84ab20f')

widen.assets.get_metadata('46579cd6-f58d-49ed-b4af-ea32c84ab20f')

widen.assets.update_metadata('46579cd6-f58d-49ed-b4af-ea32c84ab20f', {
    'fields': {
        'alternateCatalogNumber': [],
        'artist': ['Prince, Richard'],
        'artistEndYear': ['2004'],
        'artworkParentheticalTitle': [''],
        'artworkTitle': ['Untitled'],
        'artworkType': ['sculpture'],
        'description': ['This is not a dog.'],
    }
})
```

## Available Entities
The following entities are available:

- Assets (`/assets/`)
- Metadata (`/metadata/`)
